@@ -9,7 +9,7 @@ from ....models.hourselection.const import (
 from .hoursselection_helpers import HourSelectionHelpers as helpers
 from .hoursselection_helpers import HourSelectionInterimUpdate as interim
 from .hoursselection_helpers import HourSelectionCalculations as calc
-from ....models.hourselection.hourobject import HourObject, HourObjectExtended
+from ....models.hourselection.hourobject import HourObject
 from ....models.hourselection.hourselectionmodels import HourSelectionModel
 from ....models.hourselection.hourtypelist import HourTypeList
 
@@ -24,51 +24,64 @@ class HourSelectionService:
 
     def update(
         self, 
-        testhour:int = None
+        adjusted_average:float = None
         ):
-        if testhour is not None:
-            self._base_mock_hour = testhour
-        hours_ready = self._update_per_day(self.model.prices_today)
+        hours_ready = self._update_per_day(prices=self.model.prices_today, adjusted_average=adjusted_average)
         hours = self._add_remove_limited_hours(hours_ready)
         hours_tomorrow = HourObject([],[],dict())
         if self.model.prices_tomorrow is not None and len(self.model.prices_tomorrow) > 0:
-            self.model.hours.conserve_top_up = False
-            hours_tomorrow = self._add_remove_limited_hours(
-                self._update_per_day(self.model.prices_tomorrow)
-                )
-            hours, hours_tomorrow, conserve = interim.interim_avg_update(
+            tomorrow_ready = self._update_per_day(self.model.prices_tomorrow, adjusted_average=adjusted_average)
+            hours_tomorrow = self._add_remove_limited_hours(tomorrow_ready)
+            hours, hours_tomorrow = interim.interim_avg_update(
                 today=hours, 
                 tomorrow=hours_tomorrow, 
-                model =self.model
+                model =self.model,
+                adjusted_average=adjusted_average
                 )
-        self.model.hours.hours_today = hours
-        self.model.hours.hours_tomorrow = hours_tomorrow
-        self.update_hour_lists(testhour=testhour)
+            
+            self.model.hours.hours_today = self._add_remove_limited_hours(
+                HourObject(nh=hours.nh, ch=hours.ch, dyn_ch=hours.dyn_ch, pricedict=hours_ready.pricedict, offset_dict=hours_ready.offset_dict)
+                )
+            self.model.hours.hours_tomorrow = self._add_remove_limited_hours(
+                HourObject(nh=hours_tomorrow.nh, ch=hours_tomorrow.ch, dyn_ch=hours_tomorrow.dyn_ch, pricedict=tomorrow_ready.pricedict, offset_dict=tomorrow_ready.offset_dict)
+            )
+        else:
+            self.model.hours.hours_today = hours
+            self.model.hours.hours_tomorrow = hours_tomorrow
+        self.update_hour_lists()
  
-    def _update_per_day(self, prices: list) -> HourObjectExtended:
-        pricedict = dict
+    def _update_per_day(self, prices: list, adjusted_average:float = None) -> HourObject:
+        pricedict = {}
         if prices is not None and len(prices) > 1:
             pricedict = helpers._create_dict(prices)
             normalized_pricedict = helpers._create_dict(
                 calc.normalize_prices(prices)
                 )
             if stat.stdev(prices) > 0.05:
-                prices_ranked = calc.rank_prices(pricedict, normalized_pricedict)
-                ready_hours = self._determine_hours(prices_ranked, prices)
-                return HourObjectExtended(
-                    ready_hours.nh, 
-                    ready_hours.ch, 
-                    ready_hours.dyn_ch, 
-                    pricedict
+                ready_hours = self._determine_hours(
+                    calc.rank_prices(
+                        pricedict, 
+                        normalized_pricedict,
+                        adjusted_average
+                        ), 
+                        prices
+                        )
+                ret= HourObject(
+                    nh=ready_hours.nh, 
+                    ch=ready_hours.ch, 
+                    dyn_ch=ready_hours.dyn_ch, 
+                    pricedict=pricedict
                     )
-            return HourObjectExtended([], [], dict(), pricedict)
+            else:
+                ret= HourObject(nh=[], ch=[], dyn_ch={},pricedict=pricedict)
+            ret.offset_dict=calc.get_offset_dict(normalized_pricedict)
+            return ret
 
     def update_hour_lists(
         self, 
-        testhour:int = None, 
         listtype:HourTypeList = None,
         ) -> None:
-        hour = self.set_hour(testhour)
+        hour = self.set_hour()
         if listtype is not None:
             match listtype:
                 case HourTypeList.NonHour:
@@ -83,15 +96,16 @@ class HourSelectionService:
             self.model.hours.update_non_hours(hour)
             self.model.hours.update_caution_hours(hour)
             self.model.hours.update_dynanmic_caution_hours(hour)
+            self.model.hours.update_offset_dict()
 
-    def _add_remove_limited_hours(self, hours: HourObjectExtended) -> HourObject:
+    def _add_remove_limited_hours(self, hours: HourObject) -> HourObject:
         """Removes cheap hours and adds expensive hours set by user limitation"""
         if hours is None:
             return HourObject([],[],dict())
         if self.model.options.absolute_top_price is not None:
                 ret = hours.add_expensive_hours(self.model.options.absolute_top_price)
         else: 
-            ret = HourObject(hours.nh, hours.ch, hours.dyn_ch)
+            ret = HourObject(nh=hours.nh, ch=hours.ch, dyn_ch=hours.dyn_ch,offset_dict=hours.offset_dict)
         if self.model.options.min_price > 0:
             ret = hours.remove_cheap_hours(self.model.options.min_price)
         return ret
@@ -102,7 +116,10 @@ class HourSelectionService:
         _ch = []
         for p in price_list:
             _permax = self._set_permax(price_list[p]["permax"])
-            if float(price_list[p]["permax"]) <= self.model.options.cautionhour_type or float(price_list[p]["val"]) <= (sum(prices)/len(prices)):
+            if any([
+                float(price_list[p]["permax"]) <= self.model.options.cautionhour_type,
+                float(price_list[p]["val"]) <= (sum(prices)/len(prices))
+            ]):
                 _ch.append(p)
                 _dyn_ch[p] = round(_permax,2)
             else:
