@@ -8,27 +8,21 @@ _LOGGER = logging.getLogger(__name__)
 
 class HourSelectionInterimUpdate:
     @staticmethod
-    def interim_avg_update(today: HourObject, tomorrow: HourObject, model: HourSelectionModel) -> Tuple[HourObject, HourObject, bool]:
-        avg = HourSelectionInterimUpdate._get_average_price(model.prices_today, model.prices_tomorrow)
+    def interim_avg_update(today: HourObject, tomorrow: HourObject, model: HourSelectionModel, adjusted_average:float = None) -> Tuple[HourObject, HourObject]:
+        avg = HourSelectionInterimUpdate._get_average_price(model.prices_today, model.prices_tomorrow, adjusted_average)
         _today = HourSelectionInterimUpdate._set_interim_per_day(
             True,
             avg, 
             model.prices_today, 
-            today, 
-            model.options.absolute_top_price, 
-            model.options.min_price
+            today
             )
         _tomorrow = HourSelectionInterimUpdate._set_interim_per_day(
             False,
             avg, 
             model.prices_tomorrow, 
-            tomorrow,  
-            model.options.absolute_top_price, 
-            model.options.min_price
+            tomorrow
             )
-
-        conserve = True if _today[1] is True or _tomorrow[1] is True else False
-        return _today[0], _tomorrow[0], conserve
+        return _today, _tomorrow
 
     @staticmethod
     def _set_interim_per_day(
@@ -36,20 +30,15 @@ class HourSelectionInterimUpdate:
         avg: float, 
         prices: list, 
         hour_obj: HourObject, 
-        max_price: float = None, 
-        min_price: float = None, 
-        ) -> Tuple[HourObject, bool]:
+        ) -> HourObject:
         new_nonhours = []
         new_ok_hours = []
-        _max_price = float('inf') if max_price is None else max_price
-        _min_price = float('-inf') if min_price is None else min_price
-        conserve_top_up = False
 
         for idx, p in enumerate(prices):
             if (idx >= 14 and is_today) or idx < 14:
-                if p > avg or p > _max_price:
+                if p > avg:
                     new_nonhours.append(idx)
-                elif p <= avg or p <= _min_price:
+                elif p <= avg:
                     new_ok_hours.append(idx)
         
         for h in new_nonhours:
@@ -61,9 +50,6 @@ class HourSelectionInterimUpdate:
                     if h in hour_obj.dyn_ch.keys():
                         hour_obj.dyn_ch.pop(h)
         hour_obj.nh.sort()
-        
-        if len(new_nonhours) > 0 or len(new_ok_hours) > 0:
-            conserve_top_up = True
 
         for h in new_ok_hours:
             if h in hour_obj.nh:
@@ -71,14 +57,13 @@ class HourSelectionInterimUpdate:
             elif h in hour_obj.ch:
                 hour_obj.ch.remove(h)
                 hour_obj.dyn_ch.pop(h)    
-        print(hour_obj.nh)
-        return HourObject(hour_obj.nh, hour_obj.ch, hour_obj.dyn_ch), conserve_top_up
+        return HourObject(hour_obj.nh, hour_obj.ch, hour_obj.dyn_ch)
 
     @staticmethod
-    def _get_average_price(prices_today: list, prices_tomorrow:list) -> float:
+    def _get_average_price(prices_today: list, prices_tomorrow:list, adjusted_average:float = None) -> float:
         ret = prices_today[14::]
         ret[len(ret):] = prices_tomorrow[0:14]
-        return stat.mean(ret)
+        return min(stat.median(ret), stat.mean(ret))
 
 
 class HourSelectionHelpers:
@@ -87,7 +72,6 @@ class HourSelectionHelpers:
         ret = {}
         for idx, val in enumerate(input):
             ret[idx] = val
-        print(len(ret))
         if 23 <= len(ret) <= 24:
             return ret
         elif len(ret) == 25:
@@ -121,7 +105,7 @@ class HourSelectionHelpers:
             return HourSelectionHelpers._make_array_from_empty(lst)
 
     @staticmethod
-    def _make_array_from_empty(input) -> list:
+    def _make_array_from_empty(input: str) -> list:
         array = input.split(",")
         list = [p for p in array if len(p) > 0]
         ret = []
@@ -131,11 +115,11 @@ class HourSelectionHelpers:
                     parsed_item = HourSelectionHelpers._try_parse(l, float)
                     if not parsed_item:
                         parsed_item = HourSelectionHelpers._try_parse(l, int)
-                    assert type(parsed_item) is float or type(parsed_item) is int
+                    assert isinstance(parsed_item, (float,int))
                     ret.append(parsed_item)
                 return ret
             except:
-                return []
+                pass
         return []
 
 
@@ -154,20 +138,52 @@ class HourSelectionCalculations:
         return ret
 
     @staticmethod
-    def rank_prices(hourdict: dict, normalized_hourdict: dict) -> dict:
+    def rank_prices(hourdict: dict, normalized_hourdict: dict, adjusted_average:float = None) -> dict:
         ret = {}
         _maxval = max(hourdict.values())
         _max_normalized = max(normalized_hourdict.values())
-        peaqstdev = _maxval/abs(_max_normalized/stat.stdev(normalized_hourdict.values()))
-        
-        if peaqstdev < min(hourdict.values()):
-            peaqstdev = peaqstdev + min(hourdict.values())
+
+        prices_avg = stat.mean(hourdict.values())
+        if adjusted_average is not None:
+            print(f"prices_avg is: {prices_avg}")
+            print(f"maxval before: {_maxval}")
+            _maxval += (adjusted_average - prices_avg)
+            prices_avg = adjusted_average
+            print(f"adj_avg is: {prices_avg}")
+            print(f"maxval after: {_maxval}")
         for key in hourdict:
-            if hourdict[key] > peaqstdev:
+            if hourdict[key] > (prices_avg*0.7):
                 _permax = round(hourdict[key] / _maxval, 2)
                 ret[key] = {"val": hourdict[key], "permax": _permax}
         return HourSelectionCalculations._discard_excessive_hours(ret)
 
+    @staticmethod
+    def get_offset_dict(normalized_hourdict: dict):
+        ret = {}
+        _prices = [p-min(normalized_hourdict.values()) for p in normalized_hourdict.values()]
+        average_val = stat.mean(_prices)
+        for i in range(0,24):
+            try:
+                ret[i] = round((_prices[i]/average_val) - 1,2)
+            except:
+                ret[i] = 1
+        return ret
+
+    # @staticmethod
+    # def rank_prices(hourdict: dict, normalized_hourdict: dict) -> dict:
+    #     ret = {}
+    #     _maxval = max(hourdict.values())
+    #     _max_normalized = max(normalized_hourdict.values())
+    #     peaqstdev = _maxval/abs(_max_normalized/stat.stdev(normalized_hourdict.values()))
+        
+    #     if peaqstdev < min(hourdict.values()):
+    #         peaqstdev = peaqstdev + min(hourdict.values())
+    #     for key in hourdict:
+    #         if hourdict[key] > peaqstdev:
+    #             _permax = round(hourdict[key] / _maxval, 2)
+    #             ret[key] = {"val": hourdict[key], "permax": _permax}
+    #     return HourSelectionCalculations._discard_excessive_hours(ret)
+
     @staticmethod
     def _discard_excessive_hours(hours: dict):
         """There should always be at least four regular hours before absolute_top_price kicks in."""
