@@ -23,14 +23,21 @@ class Hoursselection:
         self.model = HourSelectionModel(
             options=HourSelectionOptions(
                 cautionhour_type=cautionhour_type, 
-                absolute_top_price=HourSelectionOptions.set_absolute_top_price(absolute_top_price), 
-                min_price=min_price
+                min_price=min_price,
+                absolute_top_price=HourSelectionOptions.set_absolute_top_price(
+                    absolute_top_price, 
+                    min_price
+                    )
                 )
             )
-        
         self.model.validate()
         self.service = HourSelectionService(self.model, base_mock_hour)
+        self._adjusted_average = None
     
+    @property
+    def offsets(self) -> dict:
+        return self.model.hours.offset_dict
+
     @property
     def non_hours(self) -> list:
         self.service.update_hour_lists(listtype=HourTypeList.NonHour)
@@ -67,10 +74,19 @@ class Hoursselection:
         self.model.prices_tomorrow = helpers._convert_none_list(val)
         self.update()
 
+    @property
+    def adjusted_average(self):
+        return self._adjusted_average
+
+    @adjusted_average.setter
+    def adjusted_average(self, val):
+        self._adjusted_average = val
+
     def update(self, testhour:int = None) -> None:
         if testhour is not None:
             self.service._base_mock_hour = testhour
-        self.service.update()
+        print(self.adjusted_average)
+        self.service.update(adjusted_average=self.adjusted_average)
 
     def get_average_kwh_price(self):
         ret = self._get_charge_or_price()
